@@ -2,13 +2,13 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.3-4-197
+es5id: 15.2.3.3-4-217
 description: >
     Object.getOwnPropertyDescriptor returns data desc (all false) for
-    properties on built-ins (Number.MIN_VALUE)
+    properties on built-ins (EvalError.prototype)
 ---*/
 
-var desc = Object.getOwnPropertyDescriptor(Number, "MIN_VALUE");
+var desc = Object.getOwnPropertyDescriptor(EvalError, "prototype");
 
 assert.sameValue(desc.writable, false, 'desc.writable');
 assert.sameValue(desc.enumerable, false, 'desc.enumerable');
