@@ -2,16 +2,16 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 13.2-25-s
+es5id: 13.2-26-s
 description: >
-    StrictMode - reading a property named 'arguments' of function
+    StrictMode - writing a property named 'arguments' of function
     objects is not allowed outside the function
 flags: [noStrict]
 ---*/
 
         function foo () {"use strict";}
 assert.throws(TypeError, function() {
-            var temp = foo.arguments;
+            foo.arguments = 41;
 });
 
 reportCompare(0, 0);
